# cnslab

`oslabnew` is a Python library for os lab.

## Installation

You can install `oslabnew` via pip:




This README provides a brief overview of the library, installation instructions, usage examples, and information about the license.
